@@ -1,10 +1,9 @@
 use warnings;
 use strict;
+use utf8;
 
 package Jifty;
-use IPC::PubSub 0.22;
 use Data::UUID;
-use encoding 'utf8';
 use Class::Trigger;
 
 BEGIN {
@@ -13,7 +12,7 @@ BEGIN {
     require Time::Local;
 
     # Declare early to make sure Jifty::Record::schema_version works
-    $Jifty::VERSION = '1.10518';
+    $Jifty::VERSION = '1.50430';
 }
 
 =head1 NAME
@@ -42,12 +41,6 @@ Jifty - an application framework
  # Configure information related to your application's actions
  my $api      = Jifty->api;
 
- # Make parts of your page "subscribe" to information in a fragment
- my $subs     = Jifty->subs;
-
- # Share information via IPC::PubSub in your application
- my $bus      = Jifty->bus;
-
  # Retrieve general information about Mason
  my $handler  = Jifty->handler;
 
@@ -102,7 +95,7 @@ probably a better place to start.
 use base qw/Jifty::Object/;
 use Jifty::Everything;
 
-use vars qw/$HANDLE $CONFIG $LOGGER $HANDLER $API $CLASS_LOADER $PUB_SUB $WEB @PLUGINS/;
+use vars qw/$HANDLE $CONFIG $LOGGER $HANDLER $API $CLASS_LOADER $WEB @PLUGINS/;
 
 =head1 METHODS
 
@@ -148,6 +141,7 @@ sub new {
     # Setup the defaults
     my %args = (
         no_handle        => 0,
+        no_request       => 0,
         pre_init         => 0,
         logger_component => undef,
         @_
@@ -167,16 +161,13 @@ sub new {
     push @Jifty::Record::ISA, $record_base_class unless $record_base_class eq 'Jifty::Record';
 
     # Configure the base class for Jifty::CAS
-    @Jifty::CAS::ISA = grep { $_ ne 'Jifty::CAS::Store' } @Jifty::CAS::ISA;
-    my $cas_base = Jifty->config->framework('CAS')->{'BaseClass'};
-    Jifty::Util->require( $cas_base );
-    push @Jifty::CAS::ISA, $cas_base unless $cas_base eq 'Jifty::CAS';
+    Jifty::CAS->setup;
 
     # Logger turn on
     Jifty->logger( Jifty::Logger->new( $args{'logger_component'} ) );
 
     # Set up plugins
-    my @plugins;
+    @PLUGINS = ();
     my @plugins_to_load = @{Jifty->config->framework('Plugins')};
     my $app_plugin = Jifty->app_class('Plugin');
     # we are pushing prereq to plugin, hence the 3-part for.
@@ -206,7 +197,7 @@ sub new {
             next if grep { $_ =~ $this_class } @plugins_to_load;
 
             # already loaded plugin objects
-            next if grep { ref($_) =~ $this_class } @plugins;
+            next if grep { ref($_) =~ $this_class } Jifty->plugins;
         }
 
         # Load the plugin options
@@ -219,15 +210,11 @@ sub new {
 
         # Initialize the plugin and mark the prerequisites for loading too
         my $plugin_obj = $class->new(%options);
-        push @plugins, $plugin_obj;
         foreach my $name ($plugin_obj->prereq_plugins) {
             push @plugins_to_load, {$name => {}, _prereq => 1};
         }
     }
 
-    # All plugins loaded, save them for later reference
-    Jifty->plugins(@plugins);
-
     # Now that we have the config set up and loaded plugins,
     # load the localization files.
     Jifty::I18N->refresh();
@@ -259,6 +246,12 @@ sub new {
     $app->start
         if not $args{no_handle} and $app->can('start');
 
+    # Setup an empty request and response if we're not in a web environment
+    if ($args{no_request}) {
+        Jifty->web->request(Jifty::Request->new);
+        Jifty->web->response(Jifty::Response->new);
+    }
+
     # For plugins that want all the above initialization, but want to run before
     # we begin serving requests
     Jifty->call_trigger('post_init');
@@ -372,52 +365,6 @@ sub web {
     return $Jifty::WEB ||= Jifty::Web->new();
 }
 
-=head2 subs
-
-An accessor for the L<Jifty::Subs> object that the subscription uses. 
-
-=cut
-
-sub subs {
-    return Jifty::Subs->new;
-}
-
-=head2 bus
-
-Returns an IPC::PubSub object for the current application.
-
-=cut
-
-sub bus {
-    my $class = shift;
-    my %args = ( connect => 1, @_ );
-    if (not $PUB_SUB and $args{connect}) {
-        my @args;
-
-        my $backend = Jifty->config->framework('PubSub')->{'Backend'};
-        if ( $backend eq 'Memcached' ) {
-            require IO::Socket::INET;
-
-            # If there's a running memcached on the default port. this should become configurable
-            if ( IO::Socket::INET->new('127.0.0.1:11211') ) {
-                @args = ( Jifty->app_instance_id );
-            } else {
-                $backend = 'JiftyDBI';
-            }
-        } 
-        
-        if ($backend eq 'JiftyDBI' and Jifty->handle ) {
-                @args    = (
-                    db_config    => Jifty->handle->{db_config},
-                    table_prefix => '_jifty_pubsub_',
-                );
-            }
-        $PUB_SUB = IPC::PubSub->new( $backend => @args );
-
-    }
-    return $PUB_SUB;
-}
-
 =head2 plugins
 
 Returns a list of L<Jifty::Plugin> objects for this Jifty application.
@@ -567,7 +514,7 @@ sub admin_mode {
 
 =head1 SEE ALSO
 
-L<http://jifty.org>, L<Jifty::Manual::Tutorial>, L<Jifty::Everything>, L<Jifty::Config>, L<Jifty::Handle>, L<Jifty::Logger>, L<Jifty::Handler>, L<Jifty::Web>, L<Jifty::API>, L<Jifty::Subs>, L<IPC::PubSub>, L<Jifty::Plugin>, L<Jifty::ClassLoader>
+L<http://jifty.org>, L<Jifty::Manual::Tutorial>, L<Jifty::Everything>, L<Jifty::Config>, L<Jifty::Handle>, L<Jifty::Logger>, L<Jifty::Handler>, L<Jifty::Web>, L<Jifty::API>, L<Jifty::Plugin>, L<Jifty::ClassLoader>
 
 =head1 AUTHORS
 
