@@ -190,12 +190,6 @@ sub call {
         return;
     }
 
-    # If we needed to fix up the path (it contains invalid
-    # characters) then warn, because this may cause infinite
-    # redirects
-    $self->log->warn("Redirect to '@{[$self->request->path]}' contains unsafe characters")
-        if $self->request->path =~ m{[^A-Za-z0-9\-_.!~*'()/?&;+%]};
-
     # Clone our request
     my $request = $self->request->clone;
 
@@ -255,13 +249,17 @@ sub return {
 
     # We want to preserve the current actual request environment
     # (headers, etc)
-    my $env = Jifty->web->request->top_request->env;
+    my $env     = Jifty->web->request->top_request->env;
+    my $headers = Jifty->web->request->top_request->headers;
+    # XXX TODO: should we be saving cookies too since they're no longer pulled
+    # from env as of 1d90579c4448ceba113fae1bbdfd515c021b5ae0?
 
     # Set the current request to the one in the continuation
     Jifty->web->request($self->request->clone);
 
     # Restore the environment we came in with
     Jifty->web->request->top_request->{env} = $env;
+    Jifty->web->request->top_request->headers($headers);
     Jifty->web->request->setup_subrequest_env
         if Jifty->web->request->is_subrequest;
 
