@@ -498,6 +498,11 @@ sub handle_request {
     local $SIG{__DIE__} = 'DEFAULT';
     local $Request = Jifty->web->request;
 
+    my $handler = $Dispatcher->can("fragment_handler");
+    if ($Request->is_subrequest and $handler) {
+        $handler->();
+        return undef;
+    }
     eval {
          $Dispatcher->_do_dispatch( Jifty->web->request->path);
     };
@@ -611,6 +616,7 @@ sub _do_under {
     my ( $self, $cond, $rules ) = @_;
     if ( my $regex = $self->_match($cond) ) {
 
+        $self->log->debug("Matched 'under' rule $cond as $regex for ".$self->{'path'});
         # match again to establish $1 $2 etc in the dynamic scope
         $self->{path} =~ $regex;
 
@@ -645,7 +651,7 @@ sub _do_before {
     my ( $self, $cond, $rules ) = @_;
     if ( my $regex = $self->_match($cond) ) {
 
-        $self->log->debug("Matched 'before' rule $regex for ".$self->{'path'});
+        $self->log->debug("Matched 'before' rule $cond as $regex for ".$self->{'path'});
         # match again to establish $1 $2 etc in the dynamic scope
         $self->{path} =~ $regex;
         $self->_handle_rules($rules);
@@ -663,7 +669,7 @@ sub _do_on {
     my ( $self, $cond, $rules ) = @_;
     if ( my $regex = $self->_match($cond) ) {
 
-        $self->log->debug("Matched 'on' rule $regex for ".$self->{'path'});
+        $self->log->debug("Matched 'on' rule $cond as $regex for ".$self->{'path'});
         # match again to establish $1 $2 etc in the dynamic scope
         $self->{path} =~ $regex;
         $self->_handle_rules($rules);
@@ -679,7 +685,7 @@ This method is called by the dispatcher internally. You shouldn't need to.
 sub _do_after {
     my ( $self, $cond, $rules ) = @_;
     if ( my $regex = $self->_match($cond) ) {
-        $self->log->debug("Matched 'after' rule $regex for ".$self->{'path'});
+        $self->log->debug("Matched 'after' rule $cond as $regex for ".$self->{'path'});
         # match again to establish $1 $2 etc in the dynamic scope
         $self->{path} =~ $regex;
         $self->_handle_rules($rules);
@@ -816,12 +822,6 @@ sub _do_show {
     # a relative path, prepend the working directory
     $path = "$self->{cwd}/$path" unless $path =~ m{^/};
 
-    # Check for ../../../../../etc/passwd
-    my $abs_template_path = Jifty::Util->absolute_path( Jifty->config->framework('Web')->{'TemplateRoot'} . $path );
-    my $abs_root_path = Jifty::Util->absolute_path( Jifty->config->framework('Web')->{'TemplateRoot'} );
-    Jifty->web->render_template('/errors/500')
-        if $abs_template_path !~ /^\Q$abs_root_path\E/;
-
     Jifty->web->render_template( $path );
 
     last_rule;
@@ -873,7 +873,8 @@ sub _do_dispatch {
     $self->log->debug("Dispatching request to ".$self->{path});
 
     # Disable most actions on GET requests
-    Jifty->api->deny_for_get() if $self->_match_method('GET');
+    Jifty->api->deny_for_get() if $self->_match_method('GET')
+        and not Jifty->web->request->is_subrequest;
 
     # Setup -- we we don't abort out of setup, then run the
     # actions and then the RUN stage.
@@ -1057,11 +1058,11 @@ sub _compile_condition {
         } elsif ( length($compiled) ) {
 
             # 'foo' => qr{^$cwd/foo}
-            $compiled = "(?<=\\A$self->{cwd}/)$compiled";
+            $compiled = "(?<=\\A\Q$self->{cwd}\E/)$compiled";
         } else {
 
             # empty path -- just match $cwd itself
-            $compiled = "(?<=\\A$self->{cwd})";
+            $compiled = "(?<=\\A\Q$self->{cwd}\E)";
         }
 
         if ( $Dispatcher->{rule} eq 'on' ) {
