@@ -51,36 +51,13 @@ sub new {
     my $class = shift;
     my $self = $class->SUPER::new( { @_ });
 
-    # Get a classloader set up
-    Jifty::Util->require($class->dispatcher);
-
     # XXX TODO: Add .po path
     $self->init(@_);
 
-    # XXX: If we have methods for halos, add them. Some way of detecting "are
-    # we going to be using halos" would be superb. As it stands right now,
-    # plugins are loaded, initialized, and prereq-examined in the order they're
-    # listed in the config files. Instead, each phase should be separate.
-    Jifty::Util->require("Jifty::Plugin::Halo");
-    Jifty::Util->require("Jifty::View::Mason::Halo");
+    Jifty->plugins( Jifty->plugins, $self );
 
-    if ($self->can('halo_pre_template')) {
-        Jifty::Plugin::Halo->add_trigger(
-            halo_pre_template => sub { $self->halo_pre_template(@_) },
-        );
-        Jifty::View::Mason::Halo->add_trigger(
-            halo_pre_template => sub { $self->halo_pre_template(@_) },
-        );
-    }
-
-    if ($self->can('halo_post_template')) {
-        Jifty::Plugin::Halo->add_trigger(
-            halo_post_template => sub { $self->halo_post_template(@_) },
-        );
-        Jifty::View::Mason::Halo->add_trigger(
-            halo_post_template => sub { $self->halo_post_template(@_) },
-        );
-    }
+    # Pull in the dispatcher
+    Jifty::Util->require($class->dispatcher);
 
     return $self;
 }
@@ -111,13 +88,14 @@ sub _calculate_share {
     my $self  = shift;
     my $class = ref($self);
 
+    return $self->{share} if exists $self->{share};
+
+    my $class_to_path = $class;
+    $class_to_path =~ s|::|/|g;
     unless ( $self->{share} and -d $self->{share} ) {
         # If we've got a Jifty in @INC, and the plugin is core, the
         # right thing to do is to strip off lib/ and replace it with
         # share/plugins/Jifty/Plugin/Whatever/
-        my $class_to_path = $class;
-        $class_to_path =~ s|::|/|g;
-
         $self->{share} = $INC{ $class_to_path . '.pm' };
         $self->{share} =~ s{lib/+\Q$class_to_path.pm}{share/plugins/$class_to_path};
         $self->{share} = File::Spec->rel2abs( $self->{share} );
@@ -127,9 +105,6 @@ sub _calculate_share {
         # non-core plugin in @INC.  We do this before the
         # File::ShareDir, because File::ShareDir only looks at install
         # locations, and the plugin could be hand-set in @INC.
-        my $class_to_path = $class;
-        $class_to_path =~ s|::|/|g;
-
         $self->{share} = $INC{ $class_to_path . '.pm' };
         $self->{share} =~ s{lib/+\Q$class_to_path.pm}{share};
         $self->{share} = File::Spec->rel2abs( $self->{share} );
@@ -148,8 +123,6 @@ sub _calculate_share {
         # updated plugin
 
         # Core plugins live in jifty's share/plugins/Jifty/Plugin/Whatever/
-        my $class_to_path = $class;
-        $class_to_path =~ s|::|/|g;
         $self->{share} = Jifty::Util->share_root;
         $self->{share} .= "/plugins/" . $class_to_path;
     }
