@@ -13,6 +13,7 @@ use Jifty::YAML ();
 use Jifty::JSON ();
 use Data::Dumper ();
 use XML::Simple;
+use URI::Escape ();
 
 before qr{^ (/=/ .*) \. (js|json|yml|yaml|perl|pl|xml|html) $}x => run {
     Jifty->web->request->env->{HTTP_ACCEPT} = $2;
@@ -33,6 +34,7 @@ on GET    '/=/model'            => \&list_models;
 
 on POST   '/=/model/*'          => \&create_item;
 on PUT    '/=/model/*/*/*'      => \&replace_item;
+on PUT    '/=/model/*/*/*/*'    => \&replace_item_field;
 on DELETE '/=/model/*/*/*'      => \&delete_item;
 
 on GET    '/=/search/*/**'      => \&search_items;
@@ -486,6 +488,10 @@ sub _resolve {
     return $hit;
 }
 
+sub _unescape {
+    return map { Jifty::I18N->maybe_decode_utf8( URI::Escape::uri_unescape($_) ) } @_;
+}
+
 
 =head2 list_models
 
@@ -564,7 +570,7 @@ Returns a list of items in MODELCLASS sorted by COLUMNNAME, with only COLUMNNAME
 
 sub list_model_items {
     # Normalize model name - fun!
-    my ( $model, $column ) = ( model($1), $2 );
+    my ( $model, $column ) = ( model($1), _unescape($2) );
     my $col = $model->new->collection_class->new;
     $col->unlimit;
 
@@ -589,7 +595,7 @@ Returns 404 if it doesn't exist.
 =cut
 
 sub show_item_field {
-    my ( $model, $column, $key, $field ) = ( model($1), $2, $3, $4 );
+    my ( $model, $column, $key, $field ) = ( model($1), _unescape($2, $3, $4) );
     my $rec = $model->new;
     $rec->load_by_cols( $column => $key );
     $rec->id          or abort(404);
@@ -611,7 +617,7 @@ Returns 404 if it doesn't exist.
 =cut
 
 sub show_item {
-    my ($model, $column, $key) = (model($1), $2, $3);
+    my ($model, $column, $key) = (model($1), _unescape($2, $3));
     my $rec = $model->new;
 
     # Check that the field is actually a column
@@ -659,7 +665,7 @@ Order by the given column, descending.
 sub search_items {
     my ($model, $fragment) = (model($1), $2);
     my @pieces = grep {length} split '/', $fragment;
-    my $ret = ['search', $model, @pieces];
+    my $ret = ['search', $model, _unescape(@pieces)];
 
     # limit to the key => value pairs they gave us
     my $collection = eval { $model->collection_class->new }
@@ -810,6 +816,39 @@ Implemented by redispatching to a CreateModel or UpdateModel action.
 
 sub replace_item { _dispatch_to_action('Update') }
 
+=head2 replace_item_field $model, $column, $key, $field
+
+Loads up a model of type C<$model> which has a column C<$column> with a value C<$key>.
+Sets the value of the field based on the request payload.
+Returns 404 if it doesn't exist.
+
+=cut
+
+sub replace_item_field {
+    my ( $model, $column, $key, $field ) = ( model($1), $2, $3, $4 );
+    my $rec = $model->new;
+    $rec->load_by_cols( $column => $key );
+    $rec->id          or abort(404);
+    $rec->current_user_can(update => $field) or abort (403);
+
+    # Check that the field is actually a column (and not some other method)
+    abort(404) unless valid_column($model, $field);
+
+    my $buffer;
+    Jifty->web->request->body->read($buffer, Jifty->web->request->content_length);
+
+
+
+    my $method = "set_".$field;
+    my ($val,$msg) = $rec->$method($buffer);
+
+    if (!$val) {
+        Jifty->web->response->status( 500 );
+    }
+
+    outs($msg);
+}
+
 =head2 delete_item
 
 Implemented by redispatching to a DeleteModel action.
