@@ -42,7 +42,10 @@ sub body        { $_[0]->env->{'psgi.input'} }
 sub input       { $_[0]->env->{'psgi.input'} }
 
 sub header { shift->headers->header(@_) }
-sub path { shift->uri->path(@_) }
+sub path {
+    return @_ == 1 ? $_[0]->uri->path
+                   : $_[0]->uri->path( Jifty::Util->canonicalize_path( $_[1], 1 ) )
+}
 sub content_length   { shift->headers->content_length(@_) }
 sub content_type     { shift->headers->content_type(@_) }
 sub referer          { shift->headers->referer(@_) }
@@ -257,7 +260,7 @@ sub promote {
                             template_arguments => {} );
 
     # Grab content type and posted data, if any
-    my $ct   = $req->content_type;
+    my $ct   = $req->content_type || 'application/octet-stream';
     my $data = $req->content;
 
     # Check it for something appropriate
@@ -290,7 +293,7 @@ sub from_data_structure {
     my $path = $data->{'path'};
     $path ||= $self->path || '/';
 
-    $self->path( Jifty::Util->canonicalize_path( $path, 1 ) );
+    $self->path( $path );
     $self->just_validating( $data->{validating} ) if $data->{validating};
 
     if ( ref $data->{continuation} eq "HASH" ) {
@@ -1053,6 +1056,16 @@ sub do_mapping {
         delete $self->arguments->{$_};
         $self->argument($key => $value);
     }
+    for my $request_action ($self->actions) {
+        for my $arg (keys %{$request_action->arguments || {}}) {
+            my $map = $request_action->arguments->{$arg};
+            my ($key, $value) = Jifty::Request::Mapper->map(destination => $arg, source => $map, %args);
+            next unless $key ne $arg or not defined $value or $value ne $map;
+            $request_action->delete($arg);
+            $request_action->argument($key => $value);
+            $request_action->modified(1);
+        }
+    }
     for ($self->state_variables) {
         my ($key, $value) = Jifty::Request::Mapper->map(destination => $_->key, source => $_->value, %args);
         next unless $key ne $_->key or not defined $value or $value ne $_->value;
@@ -1269,7 +1282,7 @@ will redirect to the appropriate url, with L<J:RETURN> set.
 =head3 request options
 
 The existence of C<J:VALIDATE> says that the request is only
-validating arguments.  C<J:ACTIONS> is set to a semicolon-separated
+validating arguments.  C<J:ACTIONS> is set to a exclamation mark separated
 list of monikers; the actions with those monikers will be marked
 active, while all other actions are marked inactive.  In the absence
 of C<J:ACTIONS>, all actions are active.
