@@ -26,7 +26,9 @@ starts selenium remote control for you, unless C<SELENIUM_RC_SERVER>
 is specified when the test is run.  You might also want to set
 C<SELENIUM_RC_TEST_AGAINST> to your local IP address so
 C<SELENIUM_RC_SERVER> can test against you.  C<SELENIUM_RC_BROWSER>
-tells the rc server what browser to run the tests with.
+tells the rc server what browser to run the tests with. You may want
+to set C<SELENIUM_CLASS> to a subclass of L<Test::WWW::Selenium> to
+refactor methods common to your application.
 
 =head2 rc_ok
 
@@ -59,15 +61,18 @@ sub rc_ok {
     $args{browser_url} ||= 'http://'.($ENV{SELENIUM_RC_TEST_AGAINST} || $args{test_server} || 'localhost').':'.$server->port;
 
     $args{browser} ||= $ENV{SELENIUM_RC_BROWSER} || $class->_get_default_browser;
+    $args{selenium_class} ||= $ENV{SELENIUM_CLASS} || 'Test::WWW::Selenium';
 
     $SIG{CHLD} = \&_REAPER;
 
     my $try = 5;
     my $sel;
     while ($try--) {
-        $sel = eval { Test::WWW::Selenium->new( %args, auto_stop => 0 ) };
+        $sel = eval { $args{selenium_class}->new( %args, auto_stop => 0 ) };
         last if $sel;
-        Test::More::diag "waiting for selenium rc...";
+        if ($ENV{'TEST_VERBOSE'}) {
+            Test::More::diag "waiting for selenium rc...";
+        }
         sleep 3;
     }
 
@@ -89,13 +94,14 @@ sub _REAPER {
 sub _get_default_browser {
     my $class = shift;
 
-    return '*firefox /usr/lib/mozilla-firefox/firefox';
+    return '*firefox';
 }
 
 my @cleanup;
 
 sub _start_src {
     my ($self, %args) = @_;
+    $ENV{'JIFTY_TEST_SERVER'} = 'Standalone';
     eval 'require Alien::SeleniumRC; 1'
         or die 'requires Alien::SeleniumRC to start selenium-rc.';
 
@@ -116,12 +122,21 @@ sub _start_src {
         }
         $ENV{LANG} = $args{lang} || 'en_US.UTF-8';
         $ENV{PATH} = "$ENV{PATH}:/usr/lib/firefox:/usr/lib/mozilla-firefox";
-        Test::More::diag "start selenium rc [$$]";
+        if ($ENV{'TEST_VERBOSE'}) {
+            Test::More::diag "start selenium rc [$$]";
+        }
         local $SIG{CHLD} = \&_REAPER;
         local $SIG{TERM} = sub { exit 0 };
-        Alien::SeleniumRC::start(@{ $args{args} || [] });
-        Test::More::diag "selenium rc [$$] finished.";
-        exit;
+        eval { Alien::SeleniumRC::start(@{ $args{args} || [] }) };
+        if ($@) {
+            Test::More::diag "selenium rc [$$] failed to start: $@";
+            exit 1;
+        } else {
+            if ($ENV{'TEST_VERBOSE'}) {
+                Test::More::diag "selenium rc [$$] finished.";
+            }
+            exit;
+        }
     }
 }
 
@@ -141,6 +156,7 @@ sub _skip_rest {
         for my $ct ($Tester->{Curr_Test} + 1 .. $Tester->{Expected_Tests}) {
             $Tester->skip($why); # skip rest of the test
         }
+        $Tester->done_testing();
     }
     exit(0);
 }
