@@ -41,12 +41,10 @@ __PACKAGE__->javascript_libs([qw(
     behaviour.js
     jifty.js
     jifty_utils.js
-    jifty_subs.js
     jifty_smoothscroll.js
     calendar.js
     datetime.js
     dom-drag.js
-    halo.js
     combobox.js
     key_bindings.js
     context_menu.js
@@ -61,7 +59,6 @@ __PACKAGE__->javascript_libs([qw(
     app.js
     app_behaviour.js
     css_browser_selector.js
-    cssQuery-jquery.js
     jquery.timepickr.js
     jquery.ajaxQueue.js
     jquery.bgiframe.min.js
@@ -128,6 +125,9 @@ sub url {
                 path => undef,
                 @_);
 
+    my $base_uri = URI->new(Jifty->config->framework("Web")->{BaseURL});
+    $base_uri->port(Jifty->config->framework("Web")->{Port});
+
     my $uri;
 
     my $req = Jifty->web->request;
@@ -136,34 +136,51 @@ sub url {
         $uri->path_query('/');
     }
     else {
-        $uri = URI->new(Jifty->config->framework("Web")->{BaseURL});
-        $uri->port(Jifty->config->framework("Web")->{Port});
+        $uri = $base_uri->clone;
     }
 
+    # https is sticky
+    $uri->scheme('https') if $uri->scheme eq 'http' && Jifty->web->is_ssl;
+
+    # If we're generating a URL for an email (really a Jifty::Notification
+    # subclass), force the app's configured URL rather than relying on the
+    # irrelevant current request.
+    my $level = 0;
+    while ( my $class = caller($level++) ) {
+        if ( $class->isa("Jifty::Notification") ) {
+            $uri = $base_uri->clone;
+            last;
+        }
+    }
+
+    # Always set path and scheme if they're passed explicitly
     if (defined (my $path = $args{path})) {
         # strip off leading '/' because ->canonical provides one
         $path =~ s{^/}{};
         $uri->path_query($path);
     }
 
-    # https is sticky
-    $uri->scheme('https') if $uri->scheme eq 'http' && Jifty->web->is_ssl;
-
-    # If we're generating a URL from an email (really a Jifty::Notification
-    # subclass), default to http
-    my $level = 0;
-    while ( my $class = caller($level++) ) {
-        if ( $class->isa("Jifty::Notification") ) {
-            $uri->scheme('http');
-            last;
-        }
-    }
-
     $uri->scheme( $args{'scheme'} ) if defined $args{'scheme'};
 
     return $uri->canonical->as_string;
 }
 
+=head3 static PATH
+
+Returns the URL to the static resource PATH, which is generally simply
+prepending C</static/>.  Also prepends the CDN host, if one is
+configured.
+
+=cut
+
+sub static {
+    my $class = shift;
+    my $path = shift;
+
+    my $CDN = Jifty->config->framework('Web')->{CDN} || "";
+    return "$CDN/static/$path";
+}
+
 =head3 serial 
 
 Returns a unique identifier, guaranteed to be unique within the
@@ -948,7 +965,7 @@ sub template_exists {
 
 my %TEMPLATE_CACHE;
 
-=head2 render_template PATH
+=head2 render_template PATH, [ARGS]
 
 Use our templating system to render a template.  Searches through
 L<Jifty::Handler/view_handlers> to find the first handler which
@@ -963,10 +980,19 @@ C</errors/404> if the template cannot be found.
 sub render_template {
     my $self     = shift;
     my $template = shift;
+    my $args     = shift;
     my $handler;
     my $content;
         my $void_context = ( defined wantarray ? 0 :1);
 
+    my $requested_template = $template;
+
+    # Check for ../../../../../etc/passwd
+    my $abs_template_path = Jifty::Util->absolute_path( Jifty->config->framework('Web')->{'TemplateRoot'} . $template );
+    my $abs_root_path = Jifty::Util->absolute_path( Jifty->config->framework('Web')->{'TemplateRoot'} );
+    $template = "/errors/500"
+        if $abs_template_path !~ /^\Q$abs_root_path\E/;
+
     # Look for a possible handler, and cache it for future requests.
     # With DevelMode, always look it up.
     if ( not exists $TEMPLATE_CACHE{$template} or Jifty->config->framework('DevelMode')) {
@@ -983,6 +1009,7 @@ sub render_template {
 
     # Handle 404's
     unless ($handler) {
+        Jifty->log->debug("Template '$requested_template' couldn't be found");
         return $self->render_template("/errors/404") unless defined $template and $template eq "/errors/404";
         $self->log->warn("Can't find 404 page!");
         die "ABORT";
@@ -995,7 +1022,7 @@ sub render_template {
     Jifty->handler->buffer->push( private => 1 ) unless $void_context;
 
     Jifty->handler->call_trigger("before_render_template", $handler, $template);
-    eval { $handler->show($template) };
+    eval { $handler->show($template, $args) };
 
     # Handle parse errors
     my $err = $@;
@@ -1215,7 +1242,7 @@ sub include_css {
     # if there's no trigger, 0 is returned.  if aborted/handled, undef
     # is returned.
     if ( defined $self->call_trigger( 'include_css', @_ )) {
-        $self->out( qq[<link rel="stylesheet" type="text/css" href="/static/css/$_" />\n] )
+        $self->out( qq[<link rel="stylesheet" type="text/css" href="].Jifty->web->static("css/$_").qq[" />\n] )
             for @{ Jifty->web->css_files };
     }
 
@@ -1285,7 +1312,7 @@ sub include_javascript {
     if ( defined $self->call_trigger('include_javascript', @_) ) {
         for my $file ( @{ __PACKAGE__->javascript_libs } ) {
             $self->out(
-                       qq[<script type="text/javascript" src="/static/js/$file"></script>\n]
+                       qq[<script type="text/javascript" src="].Jifty->web->static("js/$file").qq["></script>\n]
                       );
         }
     }
