@@ -29,15 +29,23 @@ specified by providing at most one of the following keys:
 
 =item append => PATH
 
-Add the given C<PATH> as a new fragment, just before the close of the
-CSS selector given by L</element>, which defaults to the end of the
-current region.
+Add the given C<PATH> as a new fragment at the end within the element
+specified by the CSS selector in L</element>.
 
 =item prepend => PATH
 
-Add the given C<PATH> as a new fragment, just after the start of the
-CSS selector given by L</element>, which defaults to the start of the
-current region.
+Add the given C<PATH> as a new fragment at the start within the element
+specified by the CSS selector in L</element>.
+
+=item before => PATH
+
+Add the given C<PATH> as a new fragment immediately before the element
+specified by the CSS selector in L</element>.
+
+=item after => PATH
+
+Add the given C<PATH> as a new fragment immediately after the element
+specified by the CSS selector in L</element>.
 
 =item popout => PATH
 
@@ -83,10 +91,12 @@ region.
 =item element => CSS SELECTOR
 
 A css selector specifying where the new region should be placed; used
-with L</append> and L</prepend>, above.  The
+with L</append>, L</prepend>, L</before>, and L</after> above.  The
 L<Jifty::Web::PageRegion/get_element> method may be useful in
 specifying elements of parent page regions.
 
+Defaults to the current region.
+
 =item submit => MONIKER
 
 A Jifty::Action, Jifty::Action moniker, hashref of 
@@ -298,7 +308,6 @@ This handler can be used with all form elements.
 
 The onkeyup event occurs when a key is released over an element. 
 This handler can be used with all form elements.
-=cut
 
 =head2 onselect
 
@@ -461,9 +470,20 @@ sub _javascript_attrs_structure {
             } elsif (exists $hook->{prepend}) {
                 @args{qw/mode path/} = ('Top', $hook->{prepend});
                 $hook->{element} ||= "#region-".$hook->{region};
+            } elsif (exists $hook->{before}) {
+                @args{qw/mode path/} = ('Before', $hook->{before});
+                $hook->{element} ||= "#region-".$hook->{region};
+            } elsif (exists $hook->{after}) {
+                @args{qw/mode path/} = ('After', $hook->{after});
+                $hook->{element} ||= "#region-".$hook->{region};
             } elsif (exists $hook->{popout}) {
                 @args{qw/mode path/} = ('Popout', $hook->{popout});
-                $hook->{element} ||= "#region-".$hook->{region};
+                # Facebox always appends to its #facebox element, but that
+                # doesn't exist before the first use so we need something
+                # that's ever present. The value doesn't matter as long as it
+                # exists.  Setting a value here means you can use Popout
+                # outside a region without specifying a value yourself.
+                $hook->{element} = "body";
             } elsif (exists $hook->{replace_with}) {
                 if (defined $hook->{replace_with}) {
                     @args{qw/mode path region/} = ('Replace', $hook->{replace_with}, $hook->{region});
@@ -559,17 +579,12 @@ sub javascript_attrs {
                     fragments    => $fragments,
                     continuation => $self->continuation,
                     preload_key  => $trigger_structure->{preload_key},
-                });
+                }, { convert_blessed => 1 });
 
-            my $update = "Jifty.update($update_json, this);";
-
-            $string .=
-                'if(event.ctrlKey||event.metaKey||event.altKey||event.shiftKey) return true; '
-                if ( $trigger eq 'onclick' );
-
-            $string .= $self->javascript_preempt
-                ? "return $update"
-                : "$update; return true;";
+            my $update = $trigger eq "onclick" ? "Jifty.c(event,$update_json,this)"
+                                               : "Jifty.update($update_json,this);";
+            $string .= "return $update";
+            $string .= " || true" unless $self->javascript_preempt;
         }
 
         if ($trigger_structure->{confirm}) {
