@@ -244,6 +244,18 @@ sub delete {
     delete $self->{children}{$key};
 }
 
+=head2 empty
+
+Removes all children of this menu.
+
+=cut
+
+sub empty {
+    my $self = shift;
+    delete $self->{children_list};
+    delete $self->{children};
+}
+
 =head2 children
 
 Returns the children of this menu item in sorted order; as an array in
@@ -269,6 +281,8 @@ sub children {
 Render this menu with HTML markup as multiple dropdowns, suitable for
 an application's menu
 
+Any arguments are passed to L<render_as_hierarchical_menu_item>.
+
 =cut
 
 sub render_as_menu {
@@ -277,7 +291,7 @@ sub render_as_menu {
     Jifty->web->out(qq{<ul class="menu">});
 
     for (@kids) {
-        $_->render_as_hierarchical_menu_item();
+        $_->render_as_hierarchical_menu_item(@_);
     }
     Jifty->web->out(qq{</ul>});
     '';
@@ -303,12 +317,16 @@ Render an <li> for this item. suitable for use in a regular or contextual
 menu. Currently renders one level of submenu, if it exists, using
 L</render_submenu>.
 
+If you pass C<expand => 0>, the javascript expansion C<span> won't be output.
+
+Any arguments are passed to L<render_submenu>.
+
 =cut
 
 sub render_as_hierarchical_menu_item {
     my $self = shift;
     my %args = (
-        class => '',
+        expand => 1,
         @_
     );
     my @kids = $self->children;
@@ -323,8 +341,9 @@ sub render_as_hierarchical_menu_item {
         $web->out(
             qq{<span class="expand"><a href="#" onclick="Jifty.ContextMenu.hideshow('}
                 . $id
-                . qq{'); return false;">&nbsp;</a></span>} );
-        $self->render_submenu( id => $id );
+                . qq{'); return false;">&nbsp;</a></span>} )
+            if delete $args{'expand'};
+        $self->render_submenu( %args, id => $id );
     }
     $web->out(qq{</li>});
     '';
@@ -338,14 +357,21 @@ suitable for use as part of a regular or contextual menu.  Called by
 L</render_as_hierarchical_menu_item>. You probably don't need to use this
 on it's own.
 
+If passed C<deep_active => 1>, then it renders active descendants recursively
+all the way down.
+
 =cut
 
 sub render_submenu {
     my $self = shift;
-    my %args = ( id => '', @_ );
+    my %args = (
+        id => '',
+        deep_active => 0,
+        @_
+    );
 
     my $web = Jifty->web;
-    $web->out(qq(<ul id="$args{id}">));
+    $web->out(qq(<ul id="$args{id}" class="submenu">));
     for ($self->children) {
         $web->out(qq{<li class="submenu }.($_->active ? 'active' : '' ).' '. ($_->class || "").qq{">});
 
@@ -353,6 +379,12 @@ sub render_submenu {
         # Either stringify the link object or output the label
         # This is really icky. XXX TODO
         $web->out( $_->as_link );
+    
+        my @kids = $_->children;
+        if ($args{'deep_active'} and $_->active and @kids) {
+            $_->render_submenu( %args, id => $web->serial );
+        }
+
         $web->out("</li>");
     }
     $web->out(qq{</ul>});
