@@ -1,6 +1,5 @@
 /*
-   Modified to fix some bugs, use a different css query engine, and to
-   to use JSAN classes.
+   Modified version. Use jQuery as css query engine.
    
    Based on Behaviour v1.1 by Ben Nolan, June 2005, which was based
    largely on the work of Simon Willison.
@@ -27,33 +26,27 @@
 
 */   
 
-JSAN.use("DOM.Events");
-JSAN.use("Upgrade.Array.push");
-
 var Behaviour = {
     list: [],
-    
+
     register: function(sheet) {
         Behaviour.list.push(sheet);
     },
     
     apply: function() {
-	var root = arguments[0];
-	if(root) root = $(root);
-
+        var root = arguments[0];
         for (var h = 0; sheet = Behaviour.list[h]; h++) {
             for (var selector in sheet) {
-		var start = new Date();
-                var elements = cssQuery(selector, root);
-
-                if ( !elements ) continue;
-
-                for (var i = 0; element = elements[i]; i++) {
-                    sheet[selector](element);
-		}
+                jQuery(selector, root).each(function() {
+                     sheet[selector](this);
+                });
             }
         }
     }
-}    
+};
 
-DOM.Events.addListener( window, "load", function() { Behaviour.apply() } );
+(function($) {
+    $(document).ready(function(){
+        Behaviour.apply();
+    });
+})(jQuery);
